﻿using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using UnityEngine;
using UnityEngine.EventSystems;
using UnityEngine.UI;

public class TrackManager : MonoBehaviour {
    [SerializeField]
    GameObject trackList;

    [SerializeField]
    GameObject trackItemPrefab;

    [SerializeField]
    Texture2D[] backgrounds;
    private int currentBackgroundIndex = 0;

    private GameObject selectedTrackItem = null;

    private void TrackBrowse()
    {
        currentBackgroundIndex = (currentBackgroundIndex + 1) % 2;
        trackList.GetComponent<RawImage>().texture = backgrounds[currentBackgroundIndex];

        if (selectedTrackItem != null)
            selectedTrackItem.GetComponentInChildren<Text>().color = Color.white;
        selectedTrackItem = trackList.transform.GetChild(2).gameObject;
        selectedTrackItem.GetComponentInChildren<Text>().color = Color.black;
    }

    // Use this for initialization
    void Start()
    {
        LoadTracks();
        TrackBrowse();
    }
	
    // Update is called once per frame
    void Update()
    {
        if (Input.GetKeyDown(KeyCode.DownArrow))
        {
            trackList.transform.GetChild(0).SetAsLastSibling();
            TrackBrowse();
        }
        if (Input.GetKeyDown(KeyCode.UpArrow))
        {
            trackList.transform.GetChild(trackList.transform.childCount - 1).SetAsFirstSibling();
            TrackBrowse();
        }
        if (InputManager.Instance.IsButtonPressed)
            StartTrack();
    }
    
    void LoadTracks()
    {
        var files = new DirectoryInfo("Assets/Tracks")
            .GetFiles("*.bpe", SearchOption.AllDirectories);

        List<TrackInfo> tracks = files.Select(s => new TrackInfo(s)).ToList();
        while (tracks.Count() < 5)
            tracks.AddRange(tracks);

        foreach (TrackInfo track in tracks)
        {
            var trackItem = Instantiate(trackItemPrefab, trackList.transform);
//            trackItem.transform.SetParent(trackList.transform);

            trackItem.AddComponent<TrackInfoHolder>().trackInfo = track;
        }
    }

    public void StartTrack()
    {
        // TODO: disable start button if nothing selected

        var holder = selectedTrackItem.GetComponent<TrackInfoHolder>();

        GameManager.Instance.CurrentTrack = holder.trackInfo;

        Destroy(this);

        GameManager.Instance.SceneTransition("InGame");
    }
}